==> haskell-ghcide-1.10.0.0-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghcide
version:              1.10.0.0
visibility:           public
id:                   ghcide-1.10.0.0-6OJ5kLz9UpsDz0xBYDkrVJ
key:                  ghcide-1.10.0.0-6OJ5kLz9UpsDz0xBYDkrVJ
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  803dab4d92d69479d6c9ade4c85b6126
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Spans.AtPoint Development.IDE.Spans.Common
    Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Logger
    Development.IDE.Types.Monitoring Development.IDE.Types.Options
    Development.IDE.Types.Shake Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghcide-1.10.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghcide-1.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-1.10.0.0-6OJ5kLz9UpsDz0xBYDkrVJ
depends:
    Diff-0.4.1-FQGoMszL7yvHgYjHqpLdBw
    Glob-0.10.2-BcJZTkVYAMPAVXEc7RmLJp
    aeson-2.1.2.1-FhTjbzRVW7jFzXz0ecy3pa
    aeson-pretty-0.8.10-JrC5wajx3uC6GTAd4J1aaE array-0.5.4.0
    async-2.2.5-cqcrAyJc5KBpUy7cUuVT7 base-4.16.4.0
    base16-bytestring-1.0.2.0-6am4HAEozKG2acVuW9SjDR binary-0.8.9.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-KEn2hkRTWhZ23pGG8K2iDV
    co-log-core-0.3.2.3-KHiGRWM1Oj6CMak12uvjyc containers-0.6.5.1
    cryptohash-sha1-0.11.101.0-6VInAVeGAVW9RCa4brCOWW
    data-default-0.7.1.1-4Q2QEONQl2rBpJbSE6OFE3 deepseq-1.4.6.1
    dependent-map-0.4.0.0-EpG8qTzFgZiIzSaG9Xt1rF
    dependent-sum-0.7.2.0-HDb3YPqOz64Hhitq53ayFN directory-1.3.6.2
    dlist-1.0-HCxoMn9TirQDgPCFxho7O
    enummapset-0.7.3.0-C99toruyLV4Ce4zd6pIUSh exceptions-0.10.4
    extra-1.7.16-9B4V23tC1fO4gqjltrnKoa filepath-1.4.2.2
    fingertree-0.1.5.0-FElNsZpmvC3Eok5oGczSRT
    focus-1.0.3.2-Jwfu6oh7j19AuFAutFheaL ghc-9.2.8 ghc-boot-9.2.8
    ghc-boot-th-9.2.8 ghc-check-0.5.0.8-3CTasC6lICa2JxxuwvrD5e
    ghc-paths-0.1.0.12-KU8OzVy7s6GithbR4F0cp
    ghc-trace-events-0.1.2.9-FI8xtj0TQjuI48HJs0fG9x
    haddock-library-1.11.0-HBjzglOsLBf3Z0ybNCzpmC
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    hie-bios-0.12.0-IsN1bCAV6pMA7pk5DFWyWe
    hie-compat-0.3.0.0-J18lPJVEz9RKJxYK1ST1Nn
    hiedb-0.4.3.0-BCKZgH5vNyGBbyVr8LRaIc
    hls-graph-1.9.0.0-HohhuQEeucDEZh1daXcrLC
    hls-plugin-api-1.6.0.0-7khGZxDAHBh4h2Xnkyxqnh
    implicit-hie-0.1.2.7-GNnXzNeS5P63RCXVYdIMYl
    implicit-hie-cradle-0.5.0.1-4AYQd8IKauAEop2Ze27jyh
    lens-5.2.3-BvPGCNowJJEJ41IL4OiKRj
    list-t-1.0.5.5-Ft78tdhkAtzGqCkrCJqrNK
    lsp-1.6.0.0-7foj1UOuw6f9vn3R2cbem6
    lsp-types-1.6.0.1-LuUFiljUvyDCoaI5RrPcwe mtl-2.2.2
    opentelemetry-0.8.0-6IG76D4X1LTBhYjppKi2nQ
    optparse-applicative-0.17.1.0-9B5O8ePYjUG8evKtX1T4ou
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1
    prettyprinter-1.7.1-9QKc54vIxCxHMYK6wYZr9m
    prettyprinter-ansi-terminal-1.1.3-JxvHxazGeKRL4N24mRqtoo
    random-1.2.1.2-F9rVStWFtZE3PBeMKQuK89
    regex-tdfa-1.3.2.2-9qhtUPQEi9W5AWI4Zc1oyW
    safe-exceptions-0.1.7.4-GPoXaqbHmse2qLBXsbf3lC
    sorted-list-0.2.2.0-5Rq9ZsbH4bJCu5DC6yICEJ
    sqlite-simple-0.4.19.0-9EjZ3R3RCT97xewrlNjTED stm-2.5.0.2
    stm-containers-1.2.1.1-FEs1H9c7AXuH3V6Rt1Gkuq
    syb-0.7.2.4-7ynUdJcB17N8mF8LpyS12V text-1.2.5.0
    text-rope-0.3-3o9dslmtje1Dz1yj93o2Vj time-1.11.1.1
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-0.2.25.1-8L6BiCnh80y1RfJtEqTngb
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-3rvz4A0dRQ942O2ubs0wBO
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghcide-1.10.0.0-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghcide
version:              1.10.0.0
visibility:           public
id:                   ghcide-1.10.0.0-2nwk1SQVy91LozTbj018Rv
key:                  ghcide-1.10.0.0-2nwk1SQVy91LozTbj018Rv
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  2595114d7270dd23f0fb61793352d87d
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Spans.AtPoint Development.IDE.Spans.Common
    Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Logger
    Development.IDE.Types.Monitoring Development.IDE.Types.Options
    Development.IDE.Types.Shake Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghcide-1.10.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghcide-1.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-1.10.0.0-2nwk1SQVy91LozTbj018Rv
depends:
    Diff-0.4.1-FQGoMszL7yvHgYjHqpLdBw
    Glob-0.10.2-BcJZTkVYAMPAVXEc7RmLJp
    aeson-2.1.2.1-EcnOkqJy6qkFyx4PSoTHhT
    aeson-pretty-0.8.10-6F4AsDc3aOUSXD3DQTCJp array-0.5.4.0
    async-2.2.5-cqcrAyJc5KBpUy7cUuVT7 base-4.16.4.0
    base16-bytestring-1.0.2.0-6am4HAEozKG2acVuW9SjDR binary-0.8.9.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-KEn2hkRTWhZ23pGG8K2iDV
    co-log-core-0.3.2.3-KHiGRWM1Oj6CMak12uvjyc containers-0.6.5.1
    cryptohash-sha1-0.11.101.0-6VInAVeGAVW9RCa4brCOWW
    data-default-0.7.1.1-4Q2QEONQl2rBpJbSE6OFE3 deepseq-1.4.6.1
    dependent-map-0.4.0.0-D5SOVArrcqHFBRxvbeBk6s
    dependent-sum-0.7.2.0-BCN8rgDXpYLDiZDihxmtoA directory-1.3.6.2
    dlist-1.0-HCxoMn9TirQDgPCFxho7O
    enummapset-0.7.3.0-E0jybwiGb6I95zymmeqIGv exceptions-0.10.4
    extra-1.7.16-EWGdPHvQLeb5EiMAbHqdrp filepath-1.4.2.2
    fingertree-0.1.5.0-FElNsZpmvC3Eok5oGczSRT
    focus-1.0.3.2-1kxKzDP0mY1KUMC7Tq0fXW ghc-9.2.8 ghc-boot-9.2.8
    ghc-boot-th-9.2.8 ghc-check-0.5.0.8-3CTasC6lICa2JxxuwvrD5e
    ghc-paths-0.1.0.12-KU8OzVy7s6GithbR4F0cp
    ghc-trace-events-0.1.2.9-FI8xtj0TQjuI48HJs0fG9x
    haddock-library-1.11.0-JpYDgY6gGwzEq2QVz4nTij
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    hie-bios-0.12.0-FnxWbyrscbHuz6hl7f9P1
    hie-compat-0.3.0.0-J18lPJVEz9RKJxYK1ST1Nn
    hiedb-0.4.3.0-Iwz27GVpUGE1IG7kDPlLc1
    hls-graph-1.9.0.0-8euLreJ1mAAFG8RhxdTsV8
    hls-plugin-api-1.6.0.0-WFIirLLqj7ILLX39b3cCg
    implicit-hie-0.1.2.7-7unpYVjiuUA7dJSMugDbAw
    implicit-hie-cradle-0.5.0.1-G26SxjHsC5fGaH552fO1e7
    lens-5.2.3-I3ec5MPKyg91QrvRMYPpyk
    list-t-1.0.5.5-FYXF0mARszX1nMJpkb7BS9
    lsp-1.6.0.0-6L8sJShQLXFEvvyFemQeyc
    lsp-types-1.6.0.1-CcisWdy83bs2cRfS460TzT mtl-2.2.2
    opentelemetry-0.8.0-6IG76D4X1LTBhYjppKi2nQ
    optparse-applicative-0.17.1.0-9B5O8ePYjUG8evKtX1T4ou
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1
    prettyprinter-1.7.1-7366Y65hgcyJTp3r9w4dh7
    prettyprinter-ansi-terminal-1.1.3-1ZK8buEiUJp3iI6d5WR83V
    random-1.2.1.2-F9rVStWFtZE3PBeMKQuK89
    regex-tdfa-1.3.2.2-Fq0cRIHdAX6K2WF7kEKKiW
    safe-exceptions-0.1.7.4-GPoXaqbHmse2qLBXsbf3lC
    sorted-list-0.2.2.0-5Rq9ZsbH4bJCu5DC6yICEJ
    sqlite-simple-0.4.19.0-9EjZ3R3RCT97xewrlNjTED stm-2.5.0.2
    stm-containers-1.2.1.1-Hjr70TzRFBpDRNMrcLInGz
    syb-0.7.2.4-7ynUdJcB17N8mF8LpyS12V text-1.2.5.0
    text-rope-0.3-3o9dslmtje1Dz1yj93o2Vj time-1.11.1.1
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-0.2.25.1-8L6BiCnh80y1RfJtEqTngb
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-DtI6Ump4gwL4XOoZ2vYwmp
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
